@@ -269,7 +269,10 @@ create_table <- function(x, show_cols = "all", use_attributes = "all",
 #' @param x The table spec.
 #' @param vars The variable name or names to define a column for.  Names may
 #' be quoted or unquoted.  If defining for multiple variables, 
-#' pass them as a vector of names.
+#' pass them as a vector of names.  If you want to pass an R variable of names,
+#' escape the values with double curly braces, i.e. \code{vars = {{myvar}}}.
+#' The curly brace escape is useful when writing functions that construct
+#' reports dynamically. 
 #' @param label The label to use for the column header.  If a label is assigned
 #' to the label column attribute, it will be used as a default.  Otherwise,
 #' the column name will be used.
@@ -430,6 +433,13 @@ define <- function(x, vars, label = NULL, format = NULL,
   # Convert list to vector
   vars_c <- unlist(vars_c)
   
+  # Deal with curly brace escape
+  if (length(vars_c) > 0) {
+    if (vars_c[[1]] == "{") { 
+      vars_c <- get(vars_c[[2]], envir = parent.frame())
+    }
+  }
+  
   # Check that variable exists in data frame
   if (!is.null(x$data) & !is.null(vars_c)) {
     if (!any(vars_c %in% names(x$data))) {
@@ -534,7 +544,11 @@ define_c <- function(var, label = NULL, format = NULL,
 #' @param vars The variable name or names to define defaults for.  Variable
 #' names may be quoted or unquoted.  The parameter will also accept 
 #' integer column positions instead of names.  For multiple variables, 
-#' pass the names or positions as a vector. 
+#' pass the names or positions as a vector. If you want to pass an R variable 
+#' of names,
+#' escape the values with double curly braces, i.e. \code{vars = {{myvar}}}.
+#' The curly brace escape is useful when writing functions that construct
+#' reports dynamically. 
 #' @param from The variable name or position that starts a column range.  
 #' If passed as a variable name, it may be quoted or unquoted.
 #' @param to The variable name or position that ends a column range. 
@@ -653,6 +667,13 @@ column_defaults <- function(x, vars = NULL, from = NULL, to = NULL, label = NULL
   # Convert list to vector
   vars_c <- unlist(vars_c)
   
+  # Deal with curly brace escape
+  if (length(vars_c) > 0) {
+    if (vars_c[[1]] == "{") { 
+      vars_c <- get(vars_c[[2]], envir = parent.frame())
+    }
+  }
+  
   # Check that variable exists in data frame
   if (!is.null(x$data) & !is.null(vars_c)) {
     if (!any(vars_c %in% names(x$data))) {
@@ -673,6 +694,17 @@ column_defaults <- function(x, vars = NULL, from = NULL, to = NULL, label = NULL
   f <- as.character(substitute(from, env = environment()))
   if (!identical(f, character(0))) {
     
+    # Deal with curly brace escape for from
+    if (length(f) > 1) {
+      if (f[[1]] == "{") { 
+        f <- f[[2]]
+        f <- gsub("{", "", f, fixed = TRUE)
+        f <- gsub("}", "", f, fixed = TRUE)
+        f <- gsub("\\n", "", f, fixed = TRUE)
+        f <- get(trimws(f), envir = parent.frame())
+      }
+    }
+    
     if (suppressWarnings(!is.na(as.integer(f))))
         f <- names(x$data)[as.integer(f)]
     
@@ -686,6 +718,17 @@ column_defaults <- function(x, vars = NULL, from = NULL, to = NULL, label = NULL
   t <- as.character(substitute(to, env = environment()))
   if (!identical(t, character(0))) {
     
+    # Deal with curly brace escape for to
+    if (length(t) > 1) {
+      if (t[[1]] == "{") { 
+        t <- t[[2]]
+        t <- gsub("{", "", t, fixed = TRUE)
+        t <- gsub("}", "", t, fixed = TRUE)
+        t <- gsub("\\n", "", t, fixed = TRUE)
+        t <- get(trimws(t), envir = parent.frame())
+      }
+    }
+    
     if (suppressWarnings(!is.na(as.integer(t))))
       t <- names(x$data)[as.integer(t)]
   
@@ -736,11 +779,13 @@ column_defaults <- function(x, vars = NULL, from = NULL, to = NULL, label = NULL
 #' @param x The table object to add spanning headers to.
 #' @param from The starting column to span.  Spanning columns are defined as
 #' range of columns 'from' and 'to'. The columns may be identified by position, 
-#' or by quoted or unquoted variable names.
+#' or by quoted or unquoted variable names. If you want to pass an R variable,
+#' escape the value with double curly braces, i.e. \code{from = {{myvar}}}.
 #' The \code{from} parameter is required.  
 #' @param to The ending column to span.  Spanning columns are defined as
 #' range of columns 'from' and 'to'. The columns may be identified by position,
-#' or by quoted or unquoted variable names.
+#' or by quoted or unquoted variable names.  If you want to pass an R variable,
+#' escape the value with double curly braces, i.e. \code{to = {{myvar}}}.
 #' The \code{to} parameter is required. 
 #' @param label The label to apply to the spanning header.
 #' @param label_align The alignment to use for the label. Valid values are 
@@ -752,6 +797,8 @@ column_defaults <- function(x, vars = NULL, from = NULL, to = NULL, label = NULL
 #' @param n The population count to use for the "N=" label on the spanning 
 #' header. The "N=" label will be formatted according to the \code{n_format}
 #' parameter on the \code{\link{create_table}} function.
+#' @param underline A TRUE or FALSE value indicating whether the spanning
+#' header should be underlined.  Default is TRUE.  
 #' @return The modified table spec.
 #' @family table
 #' @examples 
@@ -822,12 +869,36 @@ column_defaults <- function(x, vars = NULL, from = NULL, to = NULL, label = NULL
 #' #       * From Fisher's Iris Dataset
 #' @export
 spanning_header <- function(x, from, to, label = "",
-                            label_align = "center", level = 1, n = NULL) {
+                            label_align = "center", level = 1, n = NULL,
+                            underline = TRUE) {
   
   
   f <- as.character(substitute(from, env = environment()))
   t <- as.character(substitute(to, env = environment()))
   
+
+  # Deal with curly brace escape for from
+  if (length(f) > 1) {
+    if (f[[1]] == "{") { 
+      f <- f[[2]]
+      f <- gsub("{", "", f, fixed = TRUE)
+      f <- gsub("}", "", f, fixed = TRUE)
+      f <- gsub("\\n", "", f, fixed = TRUE)
+      f <- get(trimws(f), envir = parent.frame())
+    }
+  }
+  
+  # Deal with curly brace escape for to
+  if (length(t) > 1) {
+    if (t[[1]] == "{") { 
+      t <- t[[2]]
+      t <- gsub("{", "", t, fixed = TRUE)
+      t <- gsub("}", "", t, fixed = TRUE)
+      t <- gsub("\\n", "", t, fixed = TRUE)
+      t <- get(trimws(t), envir = parent.frame())
+    }
+  }
+  
   if (!is.na(suppressWarnings(as.numeric(f))))
     f <- as.numeric(f)
   
@@ -892,6 +963,7 @@ spanning_header <- function(x, from, to, label = "",
   sh$label_align = label_align
   sh$level = level
   sh$n = n
+  sh$underline = underline
 
   x$col_spans[[length(x$col_spans) + 1]] <- sh
 
@@ -966,7 +1038,10 @@ spanning_header <- function(x, from, to, label = "",
 #' }
 #' @param x The table spec.
 #' @param vars A vector of quoted or unquoted variable names from 
-#' which to create the stub.
+#' which to create the stub. If you want to pass an R variable of names,
+#' escape the values with double curly braces, i.e. \code{vars = {{myvar}}}.
+#' The curly brace escape is useful when writing functions that construct
+#' reports dynamically. 
 #' @param label The label for the report stub.  The default label is an empty
 #' string.
 #' @param label_align The alignment for the stub column label.  
@@ -1074,6 +1149,13 @@ stub <- function(x, vars, label = "", label_align = NULL,
   # Convert list to vector
   vars_c <- unlist(vars_c)
   
+  # Deal with curly brace escape
+  if (length(vars_c) > 0) {
+    if (vars_c[[1]] == "{") { 
+      vars_c <- get(vars_c[[2]], envir = parent.frame())
+    }
+  }
+  
   # Check that variable exists in data frame
   if (!is.null(x$data) & !is.null(vars_c)) {
     if (!any(vars_c %in% names(x$data))) {
@@ -1228,7 +1310,27 @@ print.table_spec <- function(x, ..., verbose = FALSE){
         
       }
     }
-    # dedupe=FALSE, id_var = FALSE, page_wrap = FALSE,
+
+    # (x, vars, label = "", label_align = NULL, 
+    # align = "left", width = NULL)
+    
+    if (!is.null(x$stub)) {
+      
+      stb <- x$stub
+      
+      cat(paste0("- stub: ", paste(stb$vars, collapse = " "), " "))
+      if (stb$label != "")
+        cat(paste0("'", stb$label, "' "))
+      
+      if (!is.null(stb$width))
+        cat(paste0("width=", stb$width, " "))
+      
+      if (!is.null(stb$align)) 
+        cat(paste0("align='", stb$align, "' "))
+      
+      cat("\n")
+      
+    }
     
     # Print column definitions
     if (!is.null(x$col_defs)) {
