@@ -643,3 +643,129 @@ test_that("pdf19: Plot with page by on plot works as expected.", {
     expect_equal(TRUE, TRUE)
   
 })
+
+
+
+test_that("test21: 8 pt report with units in inches works as expected.", {
+  
+  if (rmarkdown::pandoc_available("1.12.3")) {
+    fp <- file.path(base_path, "pdf/test21.pdf")
+    
+    tbl <- create_table(iris) 
+    
+    rpt <- create_report(fp, units = "inches", output_type = "PDF") %>%
+      page_header("Client: Experis", "Study: ABC") %>% 
+      titles("IRIS Data Frame") %>%
+      page_footer("Time", "Confidential", "Page [pg] of [tpg]") %>% 
+      options_fixed(font_size = 8) %>% 
+      add_content(tbl) 
+    
+    
+    res <- write_report(rpt)
+    
+    expect_equal(file.exists(fp), TRUE)
+  
+  } else 
+    expect_equal(TRUE, TRUE)
+})
+
+test_that("test22: 8 pt report with units in cm works as expected.", {
+  
+  if (dev & rmarkdown::pandoc_available("1.12.3")) {
+    fp <- file.path(base_path, "pdf/test22.pdf")
+    
+    
+    rpt <- create_report(fp, units = "cm", output_type = "PDF") %>%
+      page_header("Client: Experis", "Study: ABC") %>% 
+      titles("IRIS Data Frame") %>%
+      page_footer("Time", "Confidential", "Page [pg] of [tpg]") %>% 
+      options_fixed(font_size = 8) %>% 
+      add_content(create_table(iris)) 
+    
+    
+    res <- write_report(rpt)
+    
+    expect_equal(file.exists(fp), TRUE)
+  } else 
+    expect_equal(TRUE, TRUE)
+  
+})
+
+
+
+
+test_that("pdf23: RTF Table with Plot and borders works as expected.", {
+  
+  if (rmarkdown::pandoc_available("1.12.3")) {
+    library(ggplot2)
+    
+    fp <- file.path(base_path, "pdf/test23.pdf")
+    
+    p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
+    
+    
+    plt <- create_plot(p, height = 4, width = 8)
+    tbl <- create_table(mtcars[1:10, ])
+    
+    
+    rpt <- create_report(fp, output_type = "PDF") %>%
+      page_header("Client", "Study: XYZ") %>%
+      titles("Figure 1.0", "MTCARS Miles per Cylinder Plot", borders = "all") %>%
+      set_margins(top = 1, bottom = 1) %>%
+      add_content(tbl) %>%
+      add_content(plt, align = "center") %>%
+      footnotes("* Motor Trend, 1974", borders = "all") %>%
+      page_footer("Time", "Confidential", "Page [pg] of [tpg]")
+    
+    
+    res <- write_report(rpt)
+    
+    #print(res)
+    
+    expect_equal(file.exists(fp), TRUE)
+  } else
+    expect_equal(TRUE, TRUE)
+  
+})
+
+
+
+test_that("pdf24: RTF Table with Plot and borders works as expected.", {
+  
+  if (dev & rmarkdown::pandoc_available("1.12.3")) {
+    library(ggplot2)
+    
+    fp <- file.path(base_path, "pdf/test24.pdf")
+    
+    p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
+    
+    
+    plt <- create_plot(p, height = 4, width = 8) %>% 
+      titles("My plot", borders = "all") %>% 
+      footnotes("My plot footnotes", borders = "all")
+    
+    tbl <- create_table(mtcars[1:10, ]) %>% 
+      titles("My table", borders = "all") %>% 
+      footnotes("My table footnotes", borders = "all", align = "right")
+    
+    
+    rpt <- create_report(fp, output_type = "PDF") %>%
+      page_header("Client", "Study: XYZ") %>%
+      set_margins(top = 1, bottom = 1) %>%
+      add_content(tbl) %>%
+      add_content(plt, align = "center") %>%
+      page_footer("Time", "Confidential", "Page [pg] of [tpg]")
+    
+    
+    res <- write_report(rpt)
+    
+    #print(res)
+    
+    expect_equal(file.exists(fp), TRUE)
+  } else 
+    expect_equal(TRUE, TRUE)
+  
+})
+
+
+
