@@ -24,6 +24,7 @@ test_that("rtf1: Simplest table works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
+  expect_equal(res$pages, 1)
   
 })
 
@@ -43,6 +44,7 @@ test_that("rtf2: Simplest table with title works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
+  expect_equal(res$pages, 1)
   
   
 })
@@ -92,7 +94,7 @@ test_that("rtf3: Table with break between sections works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
   
 })
 
@@ -108,7 +110,7 @@ test_that("rtf4: Table that spans multiple pages breaks as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 4)
   #write_registration_file(file.path(base_path,"./rtf/reg.txt"))
 })
 
@@ -152,7 +154,7 @@ test_that("rtf5: Table with long cell and label values wraps as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
   
 })
 
@@ -187,7 +189,7 @@ test_that("rtf6: Table with spanning headers works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
   
 })
 
@@ -213,7 +215,7 @@ test_that("rtf7: Simplest RTF report with 1 in margins works as expected.", {
   res <- write_report(rpt)
 
   expect_equal(file.exists(fp), TRUE)
-
+  expect_equal(res$pages, 1)
 
 
 })
@@ -279,7 +281,7 @@ test_that("rtf8: Two page RTF report works as expected.", {
   #print(res)
 
   expect_equal(file.exists(fp), TRUE)
-
+  expect_equal(res$pages, 2)
 
 
 })
@@ -312,7 +314,7 @@ test_that("rtf9: Simplest RTF Plot works as expected.", {
   #print(res)
 
   expect_equal(file.exists(fp), TRUE)
-
+  expect_equal(res$pages, 1)
 
 
 })
@@ -348,7 +350,7 @@ test_that("rtf10: RTF Table with Plot works as expected.", {
   #print(res)
 
   expect_equal(file.exists(fp), TRUE)
-
+  expect_equal(res$pages, 2)
 
 
 })
@@ -384,7 +386,7 @@ test_that("rtf11: RTF Table with Plot on same page works as expected.", {
   #print(res)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
   
   
 })
@@ -413,7 +415,7 @@ test_that("rtf12: Table and Text output works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 2)
 
 })
 
@@ -438,7 +440,7 @@ test_that("rtf13: Very Long text output works as expected.", {
     res <- write_report(rpt)
     
     expect_equal(file.exists(fp), TRUE)
-    
+    expect_equal(res$pages, 123)
 
     
   } else {
@@ -462,7 +464,7 @@ test_that("rtf14: Simplest portrait table works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
 })
 
 
@@ -480,7 +482,7 @@ test_that("rtf15: Simplest landscape table works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
 })
 
 test_that("test16: 10 pt report with units in cm works as expected.", {
@@ -498,7 +500,7 @@ test_that("test16: 10 pt report with units in cm works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-
+  expect_equal(res$pages, 4)
   
 })
 
@@ -519,7 +521,7 @@ test_that("test17: 12 pt report with units in cm works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 5)
   
 })
 
@@ -558,7 +560,7 @@ test_that("rtf18: Plot with page by on report works as expected.", {
   #print(res)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 3)
   
   
 })
@@ -598,12 +600,12 @@ test_that("rtf19: Plot with page by on plot works as expected.", {
   #print(res)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 3)
   
   
 })
 
-
+# Problem on this one.  Title header not aligned with plot.
 test_that("test20: Title Header on Plot works as expected.", {
   
   fp <- file.path(base_path, "rtf/test20.rtf")
@@ -624,7 +626,7 @@ test_that("test20: Title Header on Plot works as expected.", {
   res <- write_report(rpt)
   
   expect_equal(file.exists(fp), TRUE)
-  
+  expect_equal(res$pages, 1)
   
 })
 
@@ -670,3 +672,116 @@ test_that("test20: Title Header on Plot works as expected.", {
 # })
 
 
+test_that("test21: 8 pt report with units in inches works as expected.", {
+  
+  fp <- file.path(base_path, "rtf/test21.rtf")
+  
+  tbl <- create_table(iris) 
+  
+  rpt <- create_report(fp, units = "inches", output_type = "RTF") %>%
+    page_header("Client: Experis", "Study: ABC") %>% 
+    titles("IRIS Data Frame") %>%
+    page_footer("Time", "Confidential", "Page [pg] of [tpg]") %>% 
+    options_fixed(font_size = 8) %>% 
+    add_content(tbl) 
+  
+  
+  res <- write_report(rpt)
+  
+  expect_equal(file.exists(fp), TRUE)
+  expect_equal(res$pages, 3)
+  
+})
+
+test_that("test22: 8 pt report with units in cm works as expected.", {
+  
+  fp <- file.path(base_path, "rtf/test22.rtf")
+  
+  
+  rpt <- create_report(fp, units = "cm", output_type = "RTF") %>%
+    page_header("Client: Experis", "Study: ABC") %>% 
+    titles("IRIS Data Frame") %>%
+    page_footer("Time", "Confidential", "Page [pg] of [tpg]") %>% 
+    options_fixed(font_size = 8) %>% 
+    add_content(create_table(iris)) 
+  
+  
+  res <- write_report(rpt)
+  
+  expect_equal(file.exists(fp), TRUE)
+  expect_equal(res$pages, 3)
+  
+})
+
+
+
+
+test_that("rtf23: RTF Table with Plot and borders works as expected.", {
+  
+  library(ggplot2)
+  
+  fp <- file.path(base_path, "rtf/test23.rtf")
+  
+  p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
+  
+  
+  plt <- create_plot(p, height = 4, width = 8)
+  tbl <- create_table(mtcars[1:10, ])
+  
+  
+  rpt <- create_report(fp, output_type = "RTF") %>%
+    page_header("Client", "Study: XYZ") %>%
+    titles("Figure 1.0", "MTCARS Miles per Cylinder Plot", borders = "all") %>%
+    set_margins(top = 1, bottom = 1) %>%
+    add_content(tbl) %>%
+    add_content(plt, align = "center") %>%
+    footnotes("* Motor Trend, 1974", borders = "all") %>%
+    page_footer("Time", "Confidential", "Page [pg] of [tpg]")
+  
+  
+  res <- write_report(rpt)
+  
+  #print(res)
+  
+  expect_equal(file.exists(fp), TRUE)
+  expect_equal(res$pages, 2)
+  
+})
+
+
+
+test_that("rtf24: RTF Table with Plot and borders works as expected.", {
+  
+  library(ggplot2)
+  
+  fp <- file.path(base_path, "rtf/test24.rtf")
+  
+  p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
+  
+  
+  plt <- create_plot(p, height = 4, width = 8) %>% 
+    titles("My plot", borders = "all") %>% 
+    footnotes("My plot footnotes", borders = "all")
+  
+  tbl <- create_table(mtcars[1:10, ]) %>% 
+    titles("My table", borders = "all") %>% 
+    footnotes("My table footnotes", borders = "all", align = "right")
+  
+  
+  rpt <- create_report(fp, output_type = "RTF") %>%
+    page_header("Client", "Study: XYZ") %>%
+    set_margins(top = 1, bottom = 1) %>%
+    add_content(tbl) %>%
+    add_content(plt, align = "center") %>%
+    page_footer("Time", "Confidential", "Page [pg] of [tpg]")
+  
+  
+  res <- write_report(rpt)
+  
+  #print(res)
+  
+  expect_equal(file.exists(fp), TRUE)
+  expect_equal(res$pages, 2)
+})
+
+
